pub struct ConversionMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on conversion resources.
It is not used directly, but through the Doubleclicksearch hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_doubleclicksearch2 as doubleclicksearch2;
use doubleclicksearch2::{Doubleclicksearch, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = Doubleclicksearch::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `get(...)`, `get_by_customer_id(...)`, `insert(...)`, `update(...)` and `update_availability(...)`
// to build up your call.
let rb = hub.conversion();Implementations
Sourceimpl<'a, C> ConversionMethods<'a, C>
impl<'a, C> ConversionMethods<'a, C>
Sourcepub fn get(
&self,
agency_id: i64,
advertiser_id: i64,
engine_account_id: i64,
end_date: i32,
row_count: i32,
start_date: i32,
start_row: u32,
) -> ConversionGetCall<'a, C>
pub fn get( &self, agency_id: i64, advertiser_id: i64, engine_account_id: i64, end_date: i32, row_count: i32, start_date: i32, start_row: u32, ) -> ConversionGetCall<'a, C>
Create a builder to help you perform the following task:
Retrieves a list of conversions from a DoubleClick Search engine account.
Arguments
agencyId- Numeric ID of the agency.advertiserId- Numeric ID of the advertiser.engineAccountId- Numeric ID of the engine account.endDate- Last date (inclusive) on which to retrieve conversions. Format is yyyymmdd.rowCount- The number of conversions to return per call.startDate- First date (inclusive) on which to retrieve conversions. Format is yyyymmdd.startRow- The 0-based starting index for retrieving conversions results.
Sourcepub fn get_by_customer_id(
&self,
customer_id: &str,
end_date: i32,
row_count: i32,
start_date: i32,
start_row: u32,
) -> ConversionGetByCustomerIdCall<'a, C>
pub fn get_by_customer_id( &self, customer_id: &str, end_date: i32, row_count: i32, start_date: i32, start_row: u32, ) -> ConversionGetByCustomerIdCall<'a, C>
Create a builder to help you perform the following task:
Retrieves a list of conversions from a DoubleClick Search engine account.
Arguments
customerId- Customer ID of a client account in the new Search Ads 360 experience.endDate- Last date (inclusive) on which to retrieve conversions. Format is yyyymmdd.rowCount- The number of conversions to return per call.startDate- First date (inclusive) on which to retrieve conversions. Format is yyyymmdd.startRow- The 0-based starting index for retrieving conversions results.
Sourcepub fn insert(&self, request: ConversionList) -> ConversionInsertCall<'a, C>
pub fn insert(&self, request: ConversionList) -> ConversionInsertCall<'a, C>
Create a builder to help you perform the following task:
Inserts a batch of new conversions into DoubleClick Search.
Arguments
request- No description provided.
Sourcepub fn update(&self, request: ConversionList) -> ConversionUpdateCall<'a, C>
pub fn update(&self, request: ConversionList) -> ConversionUpdateCall<'a, C>
Create a builder to help you perform the following task:
Updates a batch of conversions in DoubleClick Search.
Arguments
request- No description provided.
Sourcepub fn update_availability(
&self,
request: UpdateAvailabilityRequest,
) -> ConversionUpdateAvailabilityCall<'a, C>
pub fn update_availability( &self, request: UpdateAvailabilityRequest, ) -> ConversionUpdateAvailabilityCall<'a, C>
Create a builder to help you perform the following task:
Updates the availabilities of a batch of floodlight activities in DoubleClick Search.
Arguments
request- No description provided.