ReportRequestFilters

Struct ReportRequestFilters 

pub struct ReportRequestFilters {
    pub column: Option<ReportApiColumnSpec>,
    pub operator: Option<String>,
    pub values: Option<Vec<Value>>,
}
A list of filters to be applied to the report.\ The maximum number of filters per request is 300.

This type is not used in any activity, and only used as part of another schema.

Fields

column: Option<ReportApiColumnSpec>

Column to perform the filter on. This can be a DoubleClick Search column or a saved column.

operator: Option<String>

Operator to use in the filter. See the filter reference for a list of available operators.

values: Option<Vec<Value>>

A list of values to filter the column value against.\ The maximum number of filter values per request is 300.