Struct google_doubleclicksearch2::api::ReportRequestReportScope[][src]

pub struct ReportRequestReportScope {
    pub ad_group_id: Option<String>,
    pub ad_id: Option<String>,
    pub advertiser_id: Option<String>,
    pub agency_id: Option<String>,
    pub campaign_id: Option<String>,
    pub engine_account_id: Option<String>,
    pub keyword_id: Option<String>,
}

The reportScope is a set of IDs that are used to determine which subset of entities will be returned in the report. The full lineage of IDs from the lowest scoped level desired up through agency is required.

This type is not used in any activity, and only used as part of another schema.

Fields

ad_group_id: Option<String>

DS ad group ID.

ad_id: Option<String>

DS ad ID.

advertiser_id: Option<String>

DS advertiser ID.

agency_id: Option<String>

DS agency ID.

campaign_id: Option<String>

DS campaign ID.

engine_account_id: Option<String>

DS engine account ID.

keyword_id: Option<String>

DS keyword ID.