Struct google_doubleclicksearch2::api::ReportRequestTimeRange [−][src]
If metrics are requested in a report, this argument will be used to restrict the metrics to a specific time range.
This type is not used in any activity, and only used as part of another schema.
Fields
changed_attributes_since_timestamp: Option<String>Inclusive UTC timestamp in RFC format, e.g., 2013-07-16T10:16:23.555Z. See additional references on how changed attribute reports work.
changed_metrics_since_timestamp: Option<String>Inclusive UTC timestamp in RFC format, e.g., 2013-07-16T10:16:23.555Z. See additional references on how changed metrics reports work.
end_date: Option<String>Inclusive date in YYYY-MM-DD format.
start_date: Option<String>Inclusive date in YYYY-MM-DD format.