Struct google_doubleclicksearch2::api::ConversionList [−][src]
A list of conversions.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get conversion (response)
- insert conversion (request|response)
- update conversion (request|response)
Fields
conversion: Option<Vec<Conversion>>The conversions being requested.
kind: Option<String>Identifies this as a ConversionList resource. Value: the fixed string doubleclicksearch#conversionList.